@@ -38,7 +38,7 @@ typedef struct node_list_t {
 } node_list_t;
 
 void node_list_destroy(struct node_list_t* list);
-struct node_list_t* node_list_create(struct node_t* node);
+struct node_list_t* node_list_create();
 
 int node_list_add(node_list_t* list, node_t* node);
 int node_list_insert(node_list_t* list, unsigned int index, node_t* node);
